==> deepin-voice-recorder_1.3.6.1.orig.tar.gz: deepin-voice-recorder-1.3.6.1/translations/deepin-voice-recorder_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>Верзија</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-voice-recorder_1.3.9.orig.tar.gz: deepin-voice-recorder-1.3.9/translations/deepin-voice-recorder_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="59"/>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="61"/>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="63"/>
        <source>Move to trash</source>
        <translation>Премести у смеће</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="53"/>
        <source>New recording</source>
        <translation>Нови снимак</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="55"/>
        <source>Open saved directory</source>
        <translation>Отвори место чувања</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="57"/>
        <source>About</source>
        <translation>О програму</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="59"/>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="61"/>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="168"/>
        <source>Deepin Voice Recorder is a beautiful and easy to use voice recording application with simple design. It supports visual recording, recording playback, recording list management and other functions.</source>
        <translation>Дипин Снимач Гласа је леп и лак за коришћење програм једноставног дизајна. Подржава визуелно снимање, пуштање снимка, управљање листом снимака и друге функције.</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="180"/>
        <source>Deepin Voice Recorder</source>
        <translation>Дипин Снимач Гласа</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="181"/>
        <source>Version</source>
        <translation>Верзија</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Voice Recorder</source>
        <translation>Дипин Снимач Гласа</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="55"/>
        <location filename="../src/record_page.cpp" line="219"/>
        <source>New recording</source>
        <translation>Нови снимак</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recording</source>
        <translation>Снимање</translation>
    </message>
</context>
</TS>
